@@ -18,20 +18,24 @@
  *************************************************************************/
 
 #include "fs/filesystem.h"
+#include "fs/lvm2_pv.h"
 
 #include "backend/corebackend.h"
 #include "backend/corebackendmanager.h"
 
 #include "util/externalcommand.h"
 #include "util/capacity.h"
+#include "util/helpers.h"
 
 #include <blkid/blkid.h>
 
+#include <KMountPoint>
 #include <KLocalizedString>
 
 #include <QDebug>
 
 const std::array< QColor, FileSystem::__lastType > FileSystem::defaultColorCode =
+{
 {
     QColor( 220,205,175 ),
     QColor( 187,249,207 ),
@@ -59,6 +63,7 @@ const std::array< QColor, FileSystem::__lastType > FileSystem::defaultColorCode
     QColor( 242,155,104 ),
     QColor( 160,210,180 ),
     QColor( 255,170,0 )
+}
 };
 
 
@@ -116,6 +121,35 @@ FileSystem::Type FileSystem::detectFileSystem(const QString& partitionPath)
     return CoreBackendManager::self()->backend()->detectFileSystem(partitionPath);
 }
 
+QString FileSystem::detectMountPoint(FileSystem* fs, const QString& partitionPath)
+{
+    QString mountPoint = QString();
+
+    KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName);
+    mountPoints.append(KMountPoint::possibleMountPoints(KMountPoint::NeedRealDeviceName));
+
+    if (fs->type() == FileSystem::Lvm2_PV) {
+        mountPoint = FS::lvm2_pv::getVGName(partitionPath);
+    } else {
+        mountPoint = mountPoints.findByDevice(partitionPath) ?
+                     mountPoints.findByDevice(partitionPath)->mountPoint() :
+                     QString();
+    }
+    return mountPoint;
+}
+
+bool FileSystem::detectMountStatus(FileSystem* fs, const QString& partitionPath)
+{
+    bool mounted = false;
+
+    if (fs->type() == FileSystem::Lvm2_PV) {
+        mounted = FS::lvm2_pv::getVGName(partitionPath) != QString(); // FIXME: VG name is scanned twice
+    } else {
+        mounted = isMounted(partitionPath);
+    }
+    return mounted;
+}
+
 /** Reads the label for this FileSystem
     @param deviceNode the device node for the Partition the FileSystem is on
     @return the FileSystem label or an empty string in case of error
@@ -130,14 +164,22 @@ QString FileSystem::readLabel(const QString& deviceNode) const
     @param deviceNode the device node for the Partition to create the FileSystem on
     @return true if successful
 */
-bool FileSystem::create(Report& report, const QString& deviceNode) const
+bool FileSystem::create(Report& report, const QString& deviceNode)
 {
-    Q_UNUSED(report);
-    Q_UNUSED(deviceNode);
+    Q_UNUSED(report)
+    Q_UNUSED(deviceNode)
 
     return true;
 }
 
+/** Scans a new FileSystem and load file system specific class variables.
+ *  @param deviceNode the device node for the Partition to create the FileSystem on
+*/
+void FileSystem::scan(const QString& deviceNode)
+{
+    Q_UNUSED(deviceNode);
+}
+
 /** Resize a FileSystem to a given new length
     @param report Report to write status information to
     @param deviceNode the device node for the Partition the FileSystem is on
@@ -145,9 +187,26 @@ bool FileSystem::create(Report& report, const QString& deviceNode) const
     @return true on success
 */
 bool FileSystem::resize(Report& report, const QString& deviceNode, qint64 newLength) const
+{
+    Q_UNUSED(report)
+    Q_UNUSED(deviceNode)
+    Q_UNUSED(newLength)
+
+    return true;
+}
+
+/** Resize a mounted FileSystem to a given new length
+    @param report Report to write status information to
+    @param deviceNode the device node for the Partition the FileSystem is on
+    @param mountPoint the mount point where FileSystem is mounted on
+    @param newLength the new length for the FileSystem in bytes
+    @return true on success
+*/
+bool FileSystem::resizeOnline(Report& report, const QString& deviceNode, const QString& mountPoint, qint64 newLength) const
 {
     Q_UNUSED(report);
     Q_UNUSED(deviceNode);
+    Q_UNUSED(mountPoint);
     Q_UNUSED(newLength);
 
     return true;
@@ -305,33 +364,33 @@ QString FileSystem::name() const
 static const QString* typeNames()
 {
     static const QString s[] = {
-        i18nc("@item filesystem name", "unknown"),
-        i18nc("@item filesystem name", "extended"),
+        xi18nc("@item filesystem name", "unknown"),
+        xi18nc("@item filesystem name", "extended"),
 
-        i18nc("@item filesystem name", "ext2"),
-        i18nc("@item filesystem name", "ext3"),
-        i18nc("@item filesystem name", "ext4"),
-        i18nc("@item filesystem name", "linuxswap"),
-        i18nc("@item filesystem name", "fat16"),
-        i18nc("@item filesystem name", "fat32"),
-        i18nc("@item filesystem name", "ntfs"),
-        i18nc("@item filesystem name", "reiser"),
-        i18nc("@item filesystem name", "reiser4"),
-        i18nc("@item filesystem name", "xfs"),
-        i18nc("@item filesystem name", "jfs"),
-        i18nc("@item filesystem name", "hfs"),
-        i18nc("@item filesystem name", "hfsplus"),
-        i18nc("@item filesystem name", "ufs"),
-        i18nc("@item filesystem name", "unformatted"),
-        i18nc("@item filesystem name", "btrfs"),
-        i18nc("@item filesystem name", "hpfs"),
-        i18nc("@item filesystem name", "luks"),
-        i18nc("@item filesystem name", "ocfs2"),
-        i18nc("@item filesystem name", "zfs"),
-        i18nc("@item filesystem name", "exfat"),
-        i18nc("@item filesystem name", "nilfs2"),
-        i18nc("@item filesystem name", "lvm2 pv"),
-        i18nc("@item filesystem name", "f2fs"),
+        xi18nc("@item filesystem name", "ext2"),
+        xi18nc("@item filesystem name", "ext3"),
+        xi18nc("@item filesystem name", "ext4"),
+        xi18nc("@item filesystem name", "linuxswap"),
+        xi18nc("@item filesystem name", "fat16"),
+        xi18nc("@item filesystem name", "fat32"),
+        xi18nc("@item filesystem name", "ntfs"),
+        xi18nc("@item filesystem name", "reiser"),
+        xi18nc("@item filesystem name", "reiser4"),
+        xi18nc("@item filesystem name", "xfs"),
+        xi18nc("@item filesystem name", "jfs"),
+        xi18nc("@item filesystem name", "hfs"),
+        xi18nc("@item filesystem name", "hfsplus"),
+        xi18nc("@item filesystem name", "ufs"),
+        xi18nc("@item filesystem name", "unformatted"),
+        xi18nc("@item filesystem name", "btrfs"),
+        xi18nc("@item filesystem name", "hpfs"),
+        xi18nc("@item filesystem name", "luks"),
+        xi18nc("@item filesystem name", "ocfs2"),
+        xi18nc("@item filesystem name", "zfs"),
+        xi18nc("@item filesystem name", "exfat"),
+        xi18nc("@item filesystem name", "nilfs2"),
+        xi18nc("@item filesystem name", "lvm2 pv"),
+        xi18nc("@item filesystem name", "f2fs"),
     };
 
     return s;
@@ -375,13 +434,13 @@ QList<FileSystem::Type> FileSystem::types()
 /** @return printable menu title for mounting this FileSystem */
 QString FileSystem::mountTitle() const
 {
-    return i18nc("@title:menu", "Mount");
+    return xi18nc("@title:menu", "Mount");
 }
 
 /** @return printable menu title for unmounting this FileSystem */
 QString FileSystem::unmountTitle() const
 {
-    return i18nc("@title:menu", "Unmount");
+    return xi18nc("@title:menu", "Unmount");
 }
 
 /** Moves a FileSystem to a new start sector.
