@@ -193,11 +193,11 @@ static qint64 readSectorsUsedLibParted(PedDisk* pedDisk, const Partition& p)
 */
 static void readSectorsUsed(PedDisk* pedDisk, const Device& d, Partition& p, const QString& mountPoint)
 {
-    if (!mountPoint.isEmpty()) {
+    if (!mountPoint.isEmpty() && p.fileSystem().type() != FileSystem::LinuxSwap && p.fileSystem().type() != FileSystem::Lvm2_PV) {
         const KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(mountPoint);
 
         // KDiskFreeSpaceInfo does not work with swap
-        if (p.isMounted() && freeSpaceInfo.isValid() && p.fileSystem().type() != FileSystem::LinuxSwap)
+        if (p.isMounted() && freeSpaceInfo.isValid())
             p.fileSystem().setSectorsUsed(freeSpaceInfo.used() / d.logicalSize());
     }
     else if (p.fileSystem().supportGetUsed() == FileSystem::cmdSupportFileSystem)
@@ -341,7 +341,7 @@ void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
         if (fs->type() == FileSystem::Luks) {
             r |= PartitionRole::Luks;
             FS::luks* luksFs = static_cast<FS::luks*>(fs);
-            luksFs->initLUKS();
+            luksFs->initLUKS(d.logicalSize());
             QString mapperNode = luksFs->mapperName();
             mountPoint = FileSystem::detectMountPoint(fs, mapperNode);
             mounted    = FileSystem::detectMountStatus(fs, mapperNode);
